# TODO

- [x] Async data retrieval
- [x] Get dependencies from github actions
- [x] Get uv dependency from github actions
- [x] Get dependencies from pre-commit
- [x] Github auth & async
- [x] Create dependency abstract class
- [x] Use get_dependency
- [x] Implement CLI
- [x] Create changes to files
- [x] Create pull request
- [x] Add format yml files
- [x] Documentation
- [ ] Add release command
- [ ] Handle uv better (not group)
- [ ] Handle pre-commit yml extension (not yaml)
- [ ] Add tests
